package javax.swing.plaf.basic;

import java.awt.Toolkit;
import java.awt.event.InputEvent;
import java.awt.Component;
import java.awt.FontMetrics;
import javax.swing.Icon;
import javax.swing.SwingUtilities;
import java.awt.Rectangle;
import java.awt.Dimension;
import javax.swing.AbstractButton;
import sun.swing.SwingUtilities2;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.Insets;

public class BasicGraphicsUtils
{
    private static final Insets GROOVE_INSETS;
    private static final Insets ETCHED_INSETS;
    
    public BasicGraphicsUtils() {
    }
    
    public static void drawEtchedRect(Graphics graphics, int n, int n2, int n3, int n4, Color color, Color color2, Color color3, Color color4) {
        Color color5 = graphics.getColor();
        graphics.translate(n, n2);
        graphics.setColor(color);
        graphics.drawLine(0, 0, n3 - 1, 0);
        graphics.drawLine(0, 1, 0, n4 - 2);
        graphics.setColor(color2);
        graphics.drawLine(1, 1, n3 - 3, 1);
        graphics.drawLine(1, 2, 1, n4 - 3);
        graphics.setColor(color4);
        graphics.drawLine(n3 - 1, 0, n3 - 1, n4 - 1);
        graphics.drawLine(0, n4 - 1, n3 - 1, n4 - 1);
        graphics.setColor(color3);
        graphics.drawLine(n3 - 2, 1, n3 - 2, n4 - 3);
        graphics.drawLine(1, n4 - 2, n3 - 2, n4 - 2);
        graphics.translate(-n, -n2);
        graphics.setColor(color5);
    }
    
    public static Insets getEtchedInsets() {
        return BasicGraphicsUtils.ETCHED_INSETS;
    }
    
    public static void drawGroove(Graphics graphics, int n, int n2, int n3, int n4, Color color, Color color2) {
        Color color3 = graphics.getColor();
        graphics.translate(n, n2);
        graphics.setColor(color);
        graphics.drawRect(0, 0, n3 - 2, n4 - 2);
        graphics.setColor(color2);
        graphics.drawLine(1, n4 - 3, 1, 1);
        graphics.drawLine(1, 1, n3 - 3, 1);
        graphics.drawLine(0, n4 - 1, n3 - 1, n4 - 1);
        graphics.drawLine(n3 - 1, n4 - 1, n3 - 1, 0);
        graphics.translate(-n, -n2);
        graphics.setColor(color3);
    }
    
    public static Insets getGrooveInsets() {
        return BasicGraphicsUtils.GROOVE_INSETS;
    }
    
    public static void drawBezel(Graphics graphics, int n, int n2, int n3, int n4, boolean b, boolean b2, Color color, Color color2, Color color3, Color color4) {
        Color color5 = graphics.getColor();
        graphics.translate(n, n2);
        if (b && b2) {
            graphics.setColor(color2);
            graphics.drawRect(0, 0, n3 - 1, n4 - 1);
            graphics.setColor(color);
            graphics.drawRect(1, 1, n3 - 3, n4 - 3);
        }
        else if (b) {
            drawLoweredBezel(graphics, n, n2, n3, n4, color, color2, color3, color4);
        }
        else if (b2) {
            graphics.setColor(color2);
            graphics.drawRect(0, 0, n3 - 1, n4 - 1);
            graphics.setColor(color4);
            graphics.drawLine(1, 1, 1, n4 - 3);
            graphics.drawLine(2, 1, n3 - 3, 1);
            graphics.setColor(color3);
            graphics.drawLine(2, 2, 2, n4 - 4);
            graphics.drawLine(3, 2, n3 - 4, 2);
            graphics.setColor(color);
            graphics.drawLine(2, n4 - 3, n3 - 3, n4 - 3);
            graphics.drawLine(n3 - 3, 2, n3 - 3, n4 - 4);
            graphics.setColor(color2);
            graphics.drawLine(1, n4 - 2, n3 - 2, n4 - 2);
            graphics.drawLine(n3 - 2, n4 - 2, n3 - 2, 1);
        }
        else {
            graphics.setColor(color4);
            graphics.drawLine(0, 0, 0, n4 - 1);
            graphics.drawLine(1, 0, n3 - 2, 0);
            graphics.setColor(color3);
            graphics.drawLine(1, 1, 1, n4 - 3);
            graphics.drawLine(2, 1, n3 - 3, 1);
            graphics.setColor(color);
            graphics.drawLine(1, n4 - 2, n3 - 2, n4 - 2);
            graphics.drawLine(n3 - 2, 1, n3 - 2, n4 - 3);
            graphics.setColor(color2);
            graphics.drawLine(0, n4 - 1, n3 - 1, n4 - 1);
            graphics.drawLine(n3 - 1, n4 - 1, n3 - 1, 0);
        }
        graphics.translate(-n, -n2);
        graphics.setColor(color5);
    }
    
    public static void drawLoweredBezel(Graphics graphics, int n, int n2, int n3, int n4, Color color, Color color2, Color color3, Color color4) {
        graphics.setColor(color2);
        graphics.drawLine(0, 0, 0, n4 - 1);
        graphics.drawLine(1, 0, n3 - 2, 0);
        graphics.setColor(color);
        graphics.drawLine(1, 1, 1, n4 - 2);
        graphics.drawLine(1, 1, n3 - 3, 1);
        graphics.setColor(color4);
        graphics.drawLine(0, n4 - 1, n3 - 1, n4 - 1);
        graphics.drawLine(n3 - 1, n4 - 1, n3 - 1, 0);
        graphics.setColor(color3);
        graphics.drawLine(1, n4 - 2, n3 - 2, n4 - 2);
        graphics.drawLine(n3 - 2, n4 - 2, n3 - 2, 1);
    }
    
    public static void drawString(Graphics graphics, String s, int n, int n2, int n3) {
        int n4 = -1;
        if (n != 0) {
            int upperCase = Character.toUpperCase((char)n);
            int lowerCase = Character.toLowerCase((char)n);
            int index = s.indexOf(upperCase);
            int index2 = s.indexOf(lowerCase);
            if (index == -1) {
                n4 = index2;
            }
            else if (index2 == -1) {
                n4 = index;
            }
            else {
                n4 = ((index2 < index) ? index2 : index);
            }
        }
        drawStringUnderlineCharAt(graphics, s, n4, n2, n3);
    }
    
    public static void drawStringUnderlineCharAt(Graphics g, String text, int underlinedIndex, int x, int y) {
        SwingUtilities2.drawStringUnderlineCharAt(null, g, text, underlinedIndex, x, y);
    }
    
    public static void drawDashedRect(Graphics graphics, int i, int j, int n, int n2) {
        for (; i < i + n; i += 2) {
            graphics.fillRect(i, j, 1, 1);
            graphics.fillRect(i, j + n2 - 1, 1, 1);
        }
        for (; j < j + n2; j += 2) {
            graphics.fillRect(i, j, 1, 1);
            graphics.fillRect(i + n - 1, j, 1, 1);
        }
    }
    
    public static Dimension getPreferredButtonSize(AbstractButton c, int n) {
        if (c.getComponentCount() > 0) {
            return null;
        }
        Icon icon = c.getIcon();
        String text = c.getText();
        FontMetrics fontMetrics = c.getFontMetrics(c.getFont());
        Rectangle iconR = new Rectangle();
        Rectangle rectangle = new Rectangle();
        SwingUtilities.layoutCompoundLabel(c, fontMetrics, text, icon, c.getVerticalAlignment(), c.getHorizontalAlignment(), c.getVerticalTextPosition(), c.getHorizontalTextPosition(), new Rectangle(32767, 32767), iconR, rectangle, (text == null) ? 0 : n);
        Rectangle union = iconR.union(rectangle);
        Insets insets = c.getInsets();
        union.width += insets.left + insets.right;
        union.height += insets.top + insets.bottom;
        return union.getSize();
    }
    
    static boolean isLeftToRight(Component component) {
        return component.getComponentOrientation().isLeftToRight();
    }
    
    static boolean isMenuShortcutKeyDown(InputEvent inputEvent) {
        return (inputEvent.getModifiers() & Toolkit.getDefaultToolkit().getMenuShortcutKeyMask()) != 0x0;
    }
    
    static {
        GROOVE_INSETS = new Insets(2, 2, 2, 2);
        ETCHED_INSETS = new Insets(2, 2, 2, 2);
    }
}
